==> estateplat-common-1.2.4-20210220.055919-655-sources.jar: cn/gtmap/estateplat/model/trade/JcptClfHtxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "JCPT_CLFHTXX")
public class JcptClfHtxx implements Serializable {
    @Id
    String ywid;
    String htbh;
    String spfzjk;
    String spfzjkdx;
    String bazt;
    byte[] htfj;
    String zjtgzt;
    Date jysj;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getSpfzjk() {
        return spfzjk;
    }

    public void setSpfzjk(String spfzjk) {
        this.spfzjk = spfzjk;
    }

    public String getSpfzjkdx() {
        return spfzjkdx;
    }

    public void setSpfzjkdx(String spfzjkdx) {
        this.spfzjkdx = spfzjkdx;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }

    public byte[] getHtfj() {
        return htfj;
    }

    public void setHtfj(byte[] htfj) {
        this.htfj = htfj;
    }

    public String getZjtgzt() {
        return zjtgzt;
    }

    public void setZjtgzt(String zjtgzt) {
        this.zjtgzt = zjtgzt;
    }

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }
}

==> estateplat-common-1.2.4-20210409.005205-701-sources.jar: cn/gtmap/estateplat/model/trade/JcptClfHtxx.java <==
package cn.gtmap.estateplat.model.trade;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Entity
@Table(name = "JCPT_CLFHTXX")
public class JcptClfHtxx extends JcptHtxx implements Serializable {
    @Id
    String ywid;
    String htbh;
    String spfzjk;
    String spfzjkdx;
    String bazt;
    byte[] htfj;
    String zjtgzt;
    Date jysj;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getSpfzjk() {
        return spfzjk;
    }

    public void setSpfzjk(String spfzjk) {
        this.spfzjk = spfzjk;
    }

    public String getSpfzjkdx() {
        return spfzjkdx;
    }

    public void setSpfzjkdx(String spfzjkdx) {
        this.spfzjkdx = spfzjkdx;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }

    public byte[] getHtfj() {
        return htfj;
    }

    public void setHtfj(byte[] htfj) {
        this.htfj = htfj;
    }

    public String getZjtgzt() {
        return zjtgzt;
    }

    public void setZjtgzt(String zjtgzt) {
        this.zjtgzt = zjtgzt;
    }

    public Date getJysj() {
        return jysj;
    }

    public void setJysj(Date jysj) {
        this.jysj = jysj;
    }
}
